@@ -2,7 +2,8 @@
 init file
 '''
 
-__all__ = ['mesonetdownloader','mesonettools']
+__all__ = ['mesonetdownloader','mesonettools','etcalculator']
 
 from .mesonetdownloader     import MesonetDownloader
 from .mesonettools          import MesonetTools
+from .etcalculator          import ETCalculator
